@@ -16,11 +16,11 @@
 #include <QComboBox>
 #include <QGroupBox>
 #include <QLabel>
+#include <QLayout>
 #include <QMetaObject>
 #include <QMetaProperty>
-#include <QTimer>
 #include <QRadioButton>
-#include <QLayout>
+#include <QTimer>
 
 #include <KConfigSkeleton>
 
@@ -29,25 +29,15 @@ Q_GLOBAL_STATIC(MyHash, s_propertyMap)
 Q_GLOBAL_STATIC(MyHash, s_changedMap)
 
 KConfigDialogManager::KConfigDialogManager(QWidget *parent, KCoreConfigSkeleton *conf)
-    : QObject(parent), d(new KConfigDialogManagerPrivate(this))
+    : QObject(parent)
+    , d(new KConfigDialogManagerPrivate(this))
 {
     d->m_conf = conf;
     d->m_dialog = parent;
     init(true);
 }
 
-KConfigDialogManager::KConfigDialogManager(QWidget *parent, KConfigSkeleton *conf)
-    : QObject(parent), d(new KConfigDialogManagerPrivate(this))
-{
-    d->m_conf = conf;
-    d->m_dialog = parent;
-    init(true);
-}
-
-KConfigDialogManager::~KConfigDialogManager()
-{
-    delete d;
-}
+KConfigDialogManager::~KConfigDialogManager() = default;
 
 // KF6: Drop this and get signals only from metaObject and/or widget's dynamic properties kcfg_property/kcfg_propertyNotify
 void KConfigDialogManager::initMaps()
@@ -83,7 +73,7 @@ void KConfigDialogManager::initMaps()
         s_changedMap()->insert(QStringLiteral("KComboBox"), SIGNAL(activated(int)));
         s_changedMap()->insert(QStringLiteral("KFontComboBox"), SIGNAL(activated(int)));
         s_changedMap()->insert(QStringLiteral("KFontRequester"), SIGNAL(fontSelected(QFont)));
-        s_changedMap()->insert(QStringLiteral("KFontChooser"),  SIGNAL(fontSelected(QFont)));
+        s_changedMap()->insert(QStringLiteral("KFontChooser"), SIGNAL(fontSelected(QFont)));
         s_changedMap()->insert(QStringLiteral("KColorCombo"), SIGNAL(activated(QColor)));
         s_changedMap()->insert(QStringLiteral("KColorButton"), SIGNAL(changed(QColor)));
         s_changedMap()->insert(QStringLiteral("KDatePicker"), SIGNAL(dateSelected(QDate)));
@@ -94,9 +84,9 @@ void KConfigDialogManager::initMaps()
         s_changedMap()->insert(QStringLiteral("KLineEdit"), SIGNAL(textChanged(QString)));
         s_changedMap()->insert(QStringLiteral("KRestrictedLine"), SIGNAL(textChanged(QString)));
         s_changedMap()->insert(QStringLiteral("KTextEdit"), SIGNAL(textChanged()));
-        s_changedMap()->insert(QStringLiteral("KUrlRequester"),  SIGNAL(textChanged(QString)));
-        s_changedMap()->insert(QStringLiteral("KUrlComboRequester"),  SIGNAL(textChanged(QString)));
-        s_changedMap()->insert(QStringLiteral("KUrlComboBox"),  SIGNAL(urlActivated(QUrl)));
+        s_changedMap()->insert(QStringLiteral("KUrlRequester"), SIGNAL(textChanged(QString)));
+        s_changedMap()->insert(QStringLiteral("KUrlComboRequester"), SIGNAL(textChanged(QString)));
+        s_changedMap()->insert(QStringLiteral("KUrlComboBox"), SIGNAL(urlActivated(QUrl)));
         s_changedMap()->insert(QStringLiteral("KButtonGroup"), SIGNAL(changed(int)));
     }
 }
@@ -107,26 +97,18 @@ QHash<QString, QByteArray> *KConfigDialogManager::propertyMap()
     return s_propertyMap();
 }
 
-#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 32)
-QHash<QString, QByteArray> *KConfigDialogManager::changedMap()
-{
-    initMaps();
-    return s_changedMap();
-}
-#endif
-
 void KConfigDialogManager::init(bool trackChanges)
 {
     initMaps();
     d->trackChanges = trackChanges;
 
     // Go through all of the children of the widgets and find all known widgets
-    (void) parseChildren(d->m_dialog, trackChanges);
+    (void)parseChildren(d->m_dialog, trackChanges);
 }
 
 void KConfigDialogManager::addWidget(QWidget *widget)
 {
-    (void) parseChildren(widget, true);
+    (void)parseChildren(widget, true);
 }
 
 void KConfigDialogManager::setupWidget(QWidget *widget, KConfigSkeletonItem *item)
@@ -173,7 +155,7 @@ void KConfigDialogManager::setupWidget(QWidget *widget, KConfigSkeletonItem *ite
     QGroupBox *gb = qobject_cast<QGroupBox *>(widget);
     if (gb && getCustomProperty(gb).isEmpty()) {
         const KConfigSkeletonItem *item = d->m_conf->findItem(widget->objectName().mid(5));
-        if (item->property().type() == QVariant::Int) {
+        if (item->property().userType() == QMetaType::Int) {
             QObjectList children = gb->children();
             children.removeAll(gb->layout());
             const QList<QAbstractButton *> buttons = gb->findChildren<QAbstractButton *>();
@@ -203,11 +185,11 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
     }
 
     const QMetaMethod onWidgetModifiedSlot = metaObject()->method(metaObject()->indexOfSlot("onWidgetModified()"));
-    Q_ASSERT(onWidgetModifiedSlot.isValid() && metaObject()->indexOfSlot("onWidgetModified()")>=0);
+    Q_ASSERT(onWidgetModifiedSlot.isValid() && metaObject()->indexOfSlot("onWidgetModified()") >= 0);
 
     for (QObject *object : listOfChildren) {
         if (!object->isWidgetType()) {
-            continue;    // Skip non-widgets
+            continue; // Skip non-widgets
         }
 
         QWidget *childWidget = static_cast<QWidget *>(object);
@@ -231,8 +213,9 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                     if (d->allExclusiveGroupBoxes.contains(childWidget)) {
                         const QList<QAbstractButton *> buttons = childWidget->findChildren<QAbstractButton *>();
                         for (QAbstractButton *button : buttons) {
-                            connect(button, &QAbstractButton::toggled,
-                                    this, [this] { d->onWidgetModified(); });
+                            connect(button, &QAbstractButton::toggled, this, [this] {
+                                d->onWidgetModified();
+                            });
                         }
                     }
 
@@ -249,7 +232,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                             userproperty = getUserProperty(childWidget);
                         }
                         if (!userproperty.isEmpty()) {
-                            const int indexOfProperty = metaObject->indexOfProperty(userproperty);
+                            const int indexOfProperty = metaObject->indexOfProperty(userproperty.constData());
                             if (indexOfProperty != -1) {
                                 const QMetaProperty property = metaObject->property(indexOfProperty);
                                 const QMetaMethod notifySignal = property.notifySignal();
@@ -259,19 +242,18 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                                 }
                             }
                         } else {
-                            qCWarning(KCONFIG_WIDGETS_LOG) << "Don't know how to monitor widget '" << childWidget->metaObject()->className() << "' for changes!";
+                            qCWarning(KCONFIG_WIDGETS_LOG) << "Don't know how to monitor widget" << childWidget->metaObject()->className() << "for changes!";
                         }
                     } else {
-                        connect(childWidget, propertyChangeSignal,
-                                this, SLOT(onWidgetModified()));
+                        connect(childWidget, propertyChangeSignal.constData(), this, SLOT(onWidgetModified()));
                         changeSignalFound = true;
                     }
 
                     if (changeSignalFound) {
                         QComboBox *cb = qobject_cast<QComboBox *>(childWidget);
-                        if (cb && cb->isEditable())
-                            connect(cb, &QComboBox::editTextChanged,
-                                    this, &KConfigDialogManager::widgetModified);
+                        if (cb && cb->isEditable()) {
+                            connect(cb, &QComboBox::editTextChanged, this, &KConfigDialogManager::widgetModified);
+                        }
                     }
                 }
                 QGroupBox *gb = qobject_cast<QGroupBox *>(childWidget);
@@ -281,7 +263,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                     d->insideGroupBox = true;
                 }
             } else {
-                qCWarning(KCONFIG_WIDGETS_LOG) << "A widget named '" << widgetName << "' was found but there is no setting named '" << configId << "'";
+                qCWarning(KCONFIG_WIDGETS_LOG) << "A widget named" << widgetName << "was found but there is no setting named" << configId;
             }
         } else if (QLabel *label = qobject_cast<QLabel *>(childWidget)) {
             QWidget *buddy = label->buddy();
@@ -295,19 +277,19 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                 d->buddyWidget.insert(configId, childWidget);
             }
         }
-//kf5: commented out to reduce debug output
-// #ifndef NDEBUG
-//     else if (!widgetName.isEmpty() && trackChanges)
-//     {
-//       QHash<QString, QByteArray>::const_iterator changedIt = s_changedMap()->constFind(childWidget->metaObject()->className());
-//       if (changedIt != s_changedMap()->constEnd())
-//       {
-//         if ((!d->insideGroupBox || !qobject_cast<QRadioButton*>(childWidget)) &&
-//             !qobject_cast<QGroupBox*>(childWidget) &&!qobject_cast<QTabWidget*>(childWidget) )
-//           qCDebug(KCONFIG_WIDGETS_LOG) << "Widget '" << widgetName << "' (" << childWidget->metaObject()->className() << ") remains unmanaged.";
-//       }
-//     }
-// #endif
+        // kf5: commented out to reduce debug output
+        // #ifndef NDEBUG
+        //     else if (!widgetName.isEmpty() && trackChanges)
+        //     {
+        //       QHash<QString, QByteArray>::const_iterator changedIt = s_changedMap()->constFind(childWidget->metaObject()->className());
+        //       if (changedIt != s_changedMap()->constEnd())
+        //       {
+        //         if ((!d->insideGroupBox || !qobject_cast<QRadioButton*>(childWidget)) &&
+        //             !qobject_cast<QGroupBox*>(childWidget) &&!qobject_cast<QTabWidget*>(childWidget) )
+        //           qCDebug(KCONFIG_WIDGETS_LOG) << "Widget '" << widgetName << "' (" << childWidget->metaObject()->className() << ") remains unmanaged.";
+        //       }
+        //     }
+        // #endif
 
         if (bParseChildren) {
             // this widget is not known as something we can store.
@@ -333,13 +315,13 @@ void KConfigDialogManager::updateWidgets()
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting" << it.key() << "has disappeared!";
             continue;
         }
 
         if (!item->isEqual(property(widget))) {
             setProperty(widget, item->property());
-//        qCDebug(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' [" << widget->className() << "] has changed";
+            // qCDebug(KCONFIG_WIDGETS_LOG) << "The setting" << it.key() << "[" << widget->className() << "] has changed";
             changed = true;
         }
         if (item->isImmutable()) {
@@ -383,7 +365,7 @@ void KConfigDialogManager::updateSettings()
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting" << it.key() << "has disappeared!";
             continue;
         }
 
@@ -395,29 +377,33 @@ void KConfigDialogManager::updateSettings()
     }
     if (changed) {
         d->m_conf->save();
-        emit settingsChanged();
+        Q_EMIT settingsChanged();
         d->updateAllWidgetIndicators();
     }
 }
 
 QByteArray KConfigDialogManager::getUserProperty(const QWidget *widget) const
 {
-    if (!s_propertyMap()->contains(widget->metaObject()->className())) {
-        const QMetaObject *metaObject = widget->metaObject();
-        const QMetaProperty user = metaObject->userProperty();
-        if (user.isValid()) {
-            s_propertyMap()->insert(widget->metaObject()->className(), user.name());
-            //qCDebug(KCONFIG_WIDGETS_LOG) << "class name: '" << widget->metaObject()->className()
+    MyHash *map = s_propertyMap();
+    const QMetaObject *metaObject = widget->metaObject();
+    const QString className(QLatin1String(metaObject->className()));
+    auto it = map->find(className);
+    if (it == map->end()) {
+        const QMetaProperty userProp = metaObject->userProperty();
+        if (userProp.isValid()) {
+            it = map->insert(className, userProp.name());
+            // qCDebug(KCONFIG_WIDGETS_LOG) << "class name: '" << className
             //<< " 's USER property: " << metaProperty.name() << endl;
         } else {
-            return QByteArray(); //no USER property
+            return QByteArray(); // no USER property
         }
     }
+
     const QComboBox *cb = qobject_cast<const QComboBox *>(widget);
     if (cb) {
         const char *qcomboUserPropertyName = cb->QComboBox::metaObject()->userProperty().name();
         const int qcomboUserPropertyIndex = qcomboUserPropertyName ? cb->QComboBox::metaObject()->indexOfProperty(qcomboUserPropertyName) : -1;
-        const char *widgetUserPropertyName = widget->metaObject()->userProperty().name();
+        const char *widgetUserPropertyName = metaObject->userProperty().name();
         const int widgetUserPropertyIndex = widgetUserPropertyName ? cb->metaObject()->indexOfProperty(widgetUserPropertyName) : -1;
 
         // no custom user property set on subclass of QComboBox?
@@ -426,16 +412,15 @@ QByteArray KConfigDialogManager::getUserProperty(const QWidget *widget) const
         }
     }
 
-    return s_propertyMap()->value(widget->metaObject()->className());
+    return it != map->end() ? it.value() : QByteArray{};
 }
 
 QByteArray KConfigDialogManager::getCustomProperty(const QWidget *widget) const
 {
     QVariant prop(widget->property("kcfg_property"));
     if (prop.isValid()) {
-        if (!prop.canConvert(QVariant::ByteArray)) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_property on" << widget->metaObject()->className()
-                       << "is not of type ByteArray";
+        if (!prop.canConvert<QByteArray>()) {
+            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_property on" << widget->metaObject()->className() << "is not of type ByteArray";
         } else {
             return prop.toByteArray();
         }
@@ -445,7 +430,8 @@ QByteArray KConfigDialogManager::getCustomProperty(const QWidget *widget) const
 
 QByteArray KConfigDialogManager::getUserPropertyChangedSignal(const QWidget *widget) const
 {
-    QHash<QString, QByteArray>::const_iterator changedIt = s_changedMap()->constFind(widget->metaObject()->className());
+    const QString className = QLatin1String(widget->metaObject()->className());
+    auto changedIt = s_changedMap()->constFind(className);
 
     if (changedIt == s_changedMap()->constEnd()) {
         // If the class name of the widget wasn't in the monitored widgets map, then look for
@@ -453,7 +439,8 @@ QByteArray KConfigDialogManager::getUserPropertyChangedSignal(const QWidget *wid
         // widgets with KConfigXT where 'Qt::Widget' wasn't being seen a the real deal, even
         // though it was a 'QWidget'.
         if (widget->metaObject()->superClass()) {
-            changedIt = s_changedMap()->constFind(widget->metaObject()->superClass()->className());
+            const QString parentClassName = QLatin1String(widget->metaObject()->superClass()->className());
+            changedIt = s_changedMap()->constFind(parentClassName);
         }
     }
 
@@ -464,9 +451,8 @@ QByteArray KConfigDialogManager::getCustomPropertyChangedSignal(const QWidget *w
 {
     QVariant prop(widget->property("kcfg_propertyNotify"));
     if (prop.isValid()) {
-        if (!prop.canConvert(QVariant::ByteArray)) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_propertyNotify on" << widget->metaObject()->className()
-                       << "is not of type ByteArray";
+        if (!prop.canConvert<QByteArray>()) {
+            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_propertyNotify on" << widget->metaObject()->className() << "is not of type ByteArray";
         } else {
             return prop.toByteArray();
         }
@@ -505,11 +491,11 @@ void KConfigDialogManager::setProperty(QWidget *w, const QVariant &v)
         }
     }
     if (userproperty.isEmpty()) {
-        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << " widget not handled!";
+        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << "widget not handled!";
         return;
     }
 
-    w->setProperty(userproperty, v);
+    w->setProperty(userproperty.constData(), v);
 }
 
 QVariant KConfigDialogManager::property(QWidget *w) const
@@ -517,8 +503,9 @@ QVariant KConfigDialogManager::property(QWidget *w) const
     if (d->allExclusiveGroupBoxes.contains(w)) {
         const QList<QAbstractButton *> buttons = w->findChildren<QAbstractButton *>();
         for (int i = 0; i < buttons.count(); ++i) {
-            if (buttons[i]->isChecked())
+            if (buttons[i]->isChecked()) {
                 return i;
+            }
         }
         return -1;
     }
@@ -538,11 +525,11 @@ QVariant KConfigDialogManager::property(QWidget *w) const
         }
     }
     if (userproperty.isEmpty()) {
-        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << " widget not handled!";
+        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << "widget not handled!";
         return QVariant();
     }
 
-    return w->property(userproperty);
+    return w->property(userproperty.constData());
 }
 
 bool KConfigDialogManager::hasChanged() const
@@ -555,7 +542,7 @@ bool KConfigDialogManager::hasChanged() const
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting" << it.key() << "has disappeared!";
             continue;
         }
 
@@ -577,7 +564,7 @@ bool KConfigDialogManager::isDefault() const
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting" << it.key() << "has disappeared!";
             continue;
         }
 
@@ -588,8 +575,8 @@ bool KConfigDialogManager::isDefault() const
     return true;
 }
 
-KConfigDialogManagerPrivate::KConfigDialogManagerPrivate(KConfigDialogManager *q)
-    : q(q)
+KConfigDialogManagerPrivate::KConfigDialogManagerPrivate(KConfigDialogManager *qq)
+    : q(qq)
     , insideGroupBox(false)
     , defaultsIndicatorsVisible(false)
 {
@@ -605,20 +592,24 @@ void KConfigDialogManagerPrivate::setDefaultsIndicatorsVisible(bool enabled)
 
 void KConfigDialogManagerPrivate::onWidgetModified()
 {
-    const auto widget = qobject_cast<QWidget*>(q->sender());
+    const auto widget = qobject_cast<QWidget *>(q->sender());
     Q_ASSERT(widget);
 
-    if (!widget->objectName().startsWith("kcfg_")) {
-        Q_ASSERT(widget->parent()->objectName().startsWith("kcfg_"));
-        const auto configId = widget->parent()->objectName().mid(5);
-        const auto parent = qobject_cast<QWidget*>(widget->parent());
-        Q_ASSERT(parent);
-        updateWidgetIndicator(configId, parent);
-    } else {
-        const auto configId = widget->objectName().mid(5);
+    const QLatin1String prefix("kcfg_");
+    QString configId = widget->objectName();
+    if (configId.startsWith(prefix)) {
+        configId.remove(0, prefix.size());
         updateWidgetIndicator(configId, widget);
+    } else {
+        auto *parent = qobject_cast<QWidget *>(widget->parent());
+        Q_ASSERT(parent);
+        configId = parent->objectName();
+        Q_ASSERT(configId.startsWith(prefix));
+        configId.remove(0, prefix.size());
+        updateWidgetIndicator(configId, parent);
     }
-    emit q->widgetModified();
+
+    Q_EMIT q->widgetModified();
 }
 
 void KConfigDialogManagerPrivate::updateWidgetIndicator(const QString &configId, QWidget *widget)
