@@ -19,6 +19,7 @@
 #include <krecentfilesaction.h>
 #include <ktogglefullscreenaction.h>
 
+#include <optional>
 #include <type_traits>
 
 class QObject;
@@ -32,8 +33,7 @@ class KToggleFullScreenAction;
  *
  * These actions should be used instead of hardcoding menubar and
  * toolbar items.  Using these actions helps your application easily
- * conform to the KDE Human Interface Guidelines.
- * @see https://hig.kde.org/
+ * conform to the <a href="https://develop.kde.org/hig/">KDE Human Interface Guidelines</a>.
  *
  * All of the documentation for QAction holds for KStandardAction
  * also.  When in doubt on how things work, check the QAction
@@ -44,20 +44,20 @@ class KToggleFullScreenAction;
  * <b>Simple Example:</b>\n
  *
  * In general, using standard actions should be a drop in replacement
- * for regular actions.  For example, if you previously had:
+ * for regular actions. For example, if you previously had:
+ * @code
+ * QAction *newAct = new QAction(i18n("&New"),
+ *                               QIcon::fromTheme("document-new"),
+ *                               KStandardShortcut::shortcut(KStandardShortcut::New),
+ *                               this,
+ *                               &ClassFoo::fileNew,
+ *                               actionCollection());
+ * @endcode
  *
- * \code
- * QAction *newAct = new QAction(i18n("&New"), QIcon::fromTheme("document-new"),
- *                               KStandardShortcut::shortcut(KStandardShortcut::New), this,
- *                               SLOT(fileNew()), actionCollection());
- * \endcode
- *
- * You could drop that and replace it with:
- *
- * \code
- * QAction *newAct = KStandardAction::openNew(this, SLOT(fileNew()),
- *                                       actionCollection());
- * \endcode
+ * You can replace it with:
+ * @code
+ * QAction *newAct = KStandardAction::openNew(this, &ClassFoo::fileNew, actionCollection());
+ * @endcode
  *
  * <b>Non-standard Usages</b>\n
  *
@@ -174,38 +174,19 @@ enum StandardAction {
     ShowMenubar, ///< Show/Hide the menubar.
     ShowToolbar, ///< Show/Hide the toolbar.
     ShowStatusbar, ///< Show/Hide the statusbar.
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-    SaveOptions ///< @deprecated Since 5.38, no known users.
-        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 38, "No known users"),
-#elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
-    SaveOptions_DEPRECATED_DO_NOT_USE,
-#endif
     KeyBindings, ///< Display the configure key bindings dialog.
     Preferences, ///< Display the preferences/options dialog.
     ConfigureToolbars, ///< Display the toolbar configuration dialog.
-// Help Menu
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-    Help ///< @deprecated Since 5.38, use HelpContents instead.
-        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 38, "Use HelpContents instead"),
-#elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
-    Help_DEPRECATED_DO_NOT_USE,
-#endif
+    // Help Menu
     HelpContents, ///< Display the handbook of the application.
     WhatsThis, ///< Trigger the What's This cursor.
     ReportBug, ///< Open up the Report Bug dialog.
     AboutApp, ///< Display the application's About box.
     AboutKDE, ///< Display the About KDE dialog.
-    TipofDay, ///< Display the "Tip of the Day".
     // Other standard actions
     ConfigureNotifications, ///< Display the notifications configuration dialog.
     FullScreen, ///< Switch to/from full screen mode.
     Clear, ///< Clear the content of the focus widget.
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 39)
-    PasteText ///< @deprecated Since 5.39, use Paste instead.
-        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 39, "Use Paste instead"),
-#elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 39)
-    PasteText_DEPRECATED_DO_NOT_USE,
-#endif
     SwitchApplicationLanguage, ///< Display the Switch Application Language dialog.
     DeleteFile, ///< Permanently deletes files or folders. @since 5.25
     RenameFile, ///< Renames files or folders. @since 5.25
@@ -241,39 +222,32 @@ KCONFIGWIDGETS_EXPORT QAction *_k_createInternal(StandardAction id, QObject *par
  * This overloads create() to allow using the new connect syntax
  * @note if you use @c OpenRecent as @p id, you should manually connect to the urlSelected(const QUrl &)
  * signal of the returned KRecentFilesAction instead or use KStandardAction::openRecent(Receiver *, Func).
+ *
+ * If not explicitly specified, @p connectionType will be AutoConnection for all actions
+ * except for ConfigureToolbars it will be QueuedConnection.
+ *
  * @see create(StandardAction, const QObject *, const char *, QObject *)
- * @since 5.23
+ * @since 5.23 (The connectionType argument was added in 5.95)
  */
 #ifdef K_DOXYGEN
-inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject *parent)
+inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject *parent, std::optional<Qt::ConnectionType> connectionType = std::nullopt)
 #else
 template<class Receiver, class Func>
 inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *
-create(StandardAction id, const Receiver *recvr, Func slot, QObject *parent)
+create(StandardAction id, const Receiver *recvr, Func slot, QObject *parent, std::optional<Qt::ConnectionType> connectionType = std::nullopt)
 #endif
 {
     QAction *action = _k_createInternal(id, parent);
-    Qt::ConnectionType connectionType = Qt::AutoConnection;
-    if (id == ConfigureToolbars) { // bug #200815
-        connectionType = Qt::QueuedConnection;
-    }
-    QObject::connect(action, &QAction::triggered, recvr, slot, connectionType);
+    // ConfigureToolbars is special because of bug #200815
+    const Qt::ConnectionType defaultConnectionType = (id == ConfigureToolbars) ? Qt::QueuedConnection : Qt::AutoConnection;
+    QObject::connect(action, &QAction::triggered, recvr, slot, connectionType.value_or(defaultConnectionType));
     return action;
 }
 
 /**
  * This will return the internal name of a given standard action.
  */
-KCONFIGWIDGETS_EXPORT const char *name(StandardAction id);
-
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(4, 0)
-/// @deprecated Since 4.0, use name(StandardAction)
-KCONFIGWIDGETS_DEPRECATED_VERSION(4, 0, "Use KStandardAction::name(StandardAction)")
-inline const char *stdName(StandardAction act_enum)
-{
-    return name(act_enum);
-}
-#endif
+KCONFIGWIDGETS_EXPORT QString name(StandardAction id);
 
 /**
  * Returns a list of all standard names. Used by KAccelManager
@@ -561,32 +535,6 @@ KCONFIGWIDGETS_EXPORT QAction *paste(const QObject *recvr, const char *slot, QOb
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(paste, Paste)
 
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 39)
-/**
- * @deprecated since 5.39. Use paste() instead.
- */
-KCONFIGWIDGETS_EXPORT
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 39, "Use KStandardAction::paste(const QObject *, const char *, QObject *)")
-QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent);
-#endif
-
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 39)
-/**
- * @since 5.23
- * @deprecated since 5.39. Use paste() instead.
- */
-#ifdef K_DOXYGEN
-inline QAction *pasteText(const QObject *recvr, Func slot, QObject *parent);
-#else
-template<class Receiver, class Func>
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 39, "Use KStandardAction::paste(const QObject *, Func, QObject *)")
-inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *pasteText(const Receiver *recvr, Func slot, QObject *parent)
-{
-    return create(PasteText, recvr, slot, parent);
-}
-#endif // K_DOXYGEN
-#endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
-
 /**
  * Clear the content of the focus widget
  */
@@ -997,39 +945,14 @@ fullScreen(const Receiver *recvr, Func slot, QWidget *window, QObject *parent)
     return ret;
 }
 
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
 /**
- * Display the save options dialog.
- * @deprecated since 5.38
- */
-KCONFIGWIDGETS_EXPORT
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "No usage known, candidate for removal on next ABI break")
-QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent);
-#endif
-
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-/**
- * Display the save options dialog.
- * @since 5.23
- * @deprecated since 5.38
- */
-#ifdef K_DOXYGEN
-inline QAction *saveOptions(const QObject *recvr, Func slot, QObject *parent);
-#else
-template<class Receiver, class Func>
-KCONFIGWIDGETS_EXPORT KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "No usage known, candidate for removal on next ABI break") inline
-    typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *saveOptions(const Receiver *recvr, Func slot, QObject *parent)
-{
-    return create(SaveOptions, recvr, slot, parent);
-}
-#endif // K_DOXYGEN
-#endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
-
-/**
- * Display the configure key bindings dialog.
+ * Display the configure keyboard shortcuts dialog.
+ *
+ * Note that you might be able to use the pre-built KXMLGUIFactory's function:
+ * @code
+ * KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
+ * @endcode
  *
- *  Note that you might be able to use the pre-built KXMLGUIFactory's function:
- *  KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
  */
 KCONFIGWIDGETS_EXPORT QAction *keyBindings(const QObject *recvr, const char *slot, QObject *parent);
 
@@ -1085,32 +1008,6 @@ KCONFIGWIDGETS_EXPORT QAction *switchApplicationLanguage(const QObject *recvr, c
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(switchApplicationLanguage, SwitchApplicationLanguage)
 
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 23)
-/**
- * @deprecated since 5.38 Use helpContents() instead.
- */
-KCONFIGWIDGETS_EXPORT
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 23, "Use KStandardAction::helpContents(const QObject *, const char *, QObject *)")
-QAction *help(const QObject *recvr, const char *slot, QObject *parent);
-#endif
-
-#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-/**
- * @since 5.23
- * @deprecated since 5.38 Use helpContents() instead.
- */
-#ifdef K_DOXYGEN
-inline QAction *help(const QObject *recvr, Func slot, QObject *parent);
-#else
-template<class Receiver, class Func>
-KCONFIGWIDGETS_EXPORT KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "Use KStandardAction::helpContents(const QObject *, Func, QObject *)") inline
-    typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *help(const Receiver *recvr, Func slot, QObject *parent)
-{
-    return create(Help, recvr, slot, parent);
-}
-#endif // K_DOXYGEN
-#endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
-
 /**
  * Display the handbook of the application.
  */
@@ -1133,17 +1030,6 @@ KCONFIGWIDGETS_EXPORT QAction *whatsThis(const QObject *recvr, const char *slot,
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(whatsThis, WhatsThis)
 
-/**
- * Display "Tip of the Day"
- */
-KCONFIGWIDGETS_EXPORT QAction *tipOfDay(const QObject *recvr, const char *slot, QObject *parent);
-
-/**
- * Display "Tip of the Day"
- * @since 5.23
- */
-KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(tipOfDay, TipofDay)
-
 /**
  * Open up the Report Bug dialog.
  */
